from rest_framework import generics

# from releasemanager.models import SampleModel 
# from releasemanager.api.serializers import SampleModelSerializer


# class SampleModelListAPIView(generics.ListAPIView):
#     queryset = SampleModel.objects.filter(enabled=True)
#     serializer_class = SampleModelSerializer
